|
Neko 1.99.7
A portable framework for high-order spectral element flow simulations
|
#include "elem_block.h"

Go to the source code of this file.
Functions | |
| template<typename T , const int LX, const int CHUNKS> | |
| __global__ void | dudxyz_kernel_1d (T *__restrict__ du, const T *__restrict__ u, const T *__restrict__ dr, const T *__restrict__ ds, const T *__restrict__ dt, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ jacinv) |
| template<typename T , const int LX, const int EB> | |
| __global__ void | __launch_bounds__ ((LX *LX *EB)) dudxyz_kernel_kstep(T *__restrict__ du |
| if (eb==0) | |
| for (int k=0;k< LX;++k) | |
| __syncthreads () | |
| __global__ void __launch_bounds__ | ( | (LX *LX *EB) | ) |
| __syncthreads | ( | ) |

| __global__ void dudxyz_kernel_1d | ( | T *__restrict__ | du, |
| const T *__restrict__ | u, | ||
| const T *__restrict__ | dr, | ||
| const T *__restrict__ | ds, | ||
| const T *__restrict__ | dt, | ||
| const T *__restrict__ | dx, | ||
| const T *__restrict__ | dy, | ||
| const T *__restrict__ | dz, | ||
| const T *__restrict__ | jacinv | ||
| ) |
Device kernel for derivative
Definition at line 44 of file dudxyz_kernel.h.

| for | ( | ) |
| if | ( | eb | = = 0 | ) |
Definition at line 150 of file dudxyz_kernel.h.
Definition at line 142 of file dudxyz_kernel.h.
Definition at line 115 of file dudxyz_kernel.h.
Definition at line 116 of file dudxyz_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dt |
Definition at line 117 of file dudxyz_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dx |
Definition at line 118 of file dudxyz_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dy |
Definition at line 119 of file dudxyz_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dz |
Definition at line 120 of file dudxyz_kernel.h.
| const int e_blk = blockIdx.x * EB + eb |
Definition at line 138 of file dudxyz_kernel.h.
Definition at line 137 of file dudxyz_kernel.h.
| const int i = threadIdx.x |
Definition at line 146 of file dudxyz_kernel.h.
Definition at line 145 of file dudxyz_kernel.h.
| __global__ void const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ jacinv |
Definition at line 121 of file dudxyz_kernel.h.
Definition at line 122 of file dudxyz_kernel.h.
Definition at line 157 of file dudxyz_kernel.h.
Definition at line 158 of file dudxyz_kernel.h.
Definition at line 159 of file dudxyz_kernel.h.
Definition at line 160 of file dudxyz_kernel.h.
Definition at line 156 of file dudxyz_kernel.h.
| __shared__ T shdx[LX *LX] |
Definition at line 126 of file dudxyz_kernel.h.
| __shared__ T shdy[LX *LX] |
Definition at line 127 of file dudxyz_kernel.h.
| __shared__ T shdz[LX *LX] |
Definition at line 128 of file dudxyz_kernel.h.
Definition at line 114 of file dudxyz_kernel.h.